@@ -9,7 +9,7 @@ from abc import ABC, abstractmethod
 
 from tqdm.auto import tqdm
 
-from ai_transform.helpers import format_logging_info
+from ai_transform.logger import format_logging_info
 from ai_transform.types import Filter
 from ai_transform.dataset.dataset import Dataset
 from ai_transform.operator.abstract_operator import AbstractOperator
